==> enb-babel-0.3.3.tgz: package/techs/js-babel.js <==
var path = require('path'),
    babel = require('babel'),
    _ = require('lodash'),
    Concat = require('concat-with-sourcemaps'),
    uniqConcat = require('unique-concat'),
    fs = require('fs'),
    vow = require('vow'),
    sourcemap = require('../lib/sourcemap');

module.exports = require('enb/lib/build-flow').create()
    .name('js-babel')
    .target('target', '?.browser.js')
    .defineOption('babelOptions')
    .useFileList(['vanilla.js', 'js', 'browser.js', 'jsx'])
    .builder(function (files) {

        var babelOptions = _.merge(this._options.babelOptions || {}, {
            externalHelpers: 'var'
        });

        var concat = new Concat(true, 'all.js', '\n');

        var target = this.node.resolvePath(this._target);

        return vow.all(files.map(function (arg) {
            var def = vow.defer();

            babel.transformFile(
                arg.fullname,
                _.merge(
                    {filenameRelative : "/" + path.relative(process.cwd(), arg.fullname)},
                    babelOptions
                ),
                function(err, result) {
                    if (err) {
                        def.reject(err);
                    } else {
                        def.resolve({file : arg, result : result});
                    }
                }
            );

            return def.promise();

        })).then(function (res) {

            var usedHelpers = [],
                concatArgs = [];

            res.forEach(function(transform) {

                var node,
                    result = transform.result;
                    file = transform.file;

                if (result.metadata.usedHelpers) {
                    usedHelpers = uniqConcat(usedHelpers, result.metadata.usedHelpers);
                }

                if (result.map) {
                    concatArgs.push([file.fullname, result.code, result.map]);
                } else {
                    node = sourcemap.generate(file.fullname, result.code);
                    concatArgs.push([
                        sourcemap.normalizeFileName(file.fullname),
                        result.code,
                        JSON.parse(node.map.toString())
                    ]);
                }
            });

            var babelHelpers = babel.buildExternalHelpers(usedHelpers);
            var babelHelpersSourceMap = sourcemap.generate('babelHelpers.js', babelHelpers);
            var babelHelpersSourceMapEncoded = JSON.parse(babelHelpersSourceMap.map.toString());

            concat.add('babelHelpers.js', babelHelpers, babelHelpersSourceMapEncoded);

            concatArgs.forEach(function(arg) {
                concat.add.apply(concat, arg);
            });

            fs.writeFileSync(target + '.map', concat.sourceMap);
            return concat.content;
        });
    })
    .createTech();

==> enb-babel-0.4.0-rc.0.tgz: package/techs/js-babel.js <==
var path = require('path'),
    babel = require('babel'),
    _ = require('lodash'),
    Concat = require('concat-with-sourcemaps'),
    uniqConcat = require('unique-concat'),
    fs = require('fs'),
    vow = require('vow'),
    fsCache = require('../lib/fs-cache'),
    sourcemap = require('../lib/sourcemap');

module.exports = require('enb/lib/build-flow').create()
    .name('js-babel')
    .target('target', '?.browser.js')
    .defineOption('babelOptions')
    .useFileList(['vanilla.js', 'js', 'browser.js', 'jsx'])
    .builder(function (files) {

        var babelOptions = _.merge(this._options.babelOptions || {}, {
            externalHelpers: 'var',
            ast: false,
        });

        var concat = new Concat(true, 'all.js', '\n');
        var target = this.node.resolvePath(this._target);

        return vow.all(files.map(function (arg) {
            var def = vow.defer();

            var finalOptions = _.merge(
                {
                    filename: arg.fullname,
                    filenameRelative : "/" + path.relative(process.cwd(), arg.fullname)
                },
                babelOptions
            );

            fsCache({
                    directory: '.enb/babel',
                    identifier: arg.fullname,
                    source: fs.readFileSync(arg.fullname),
                    options: finalOptions,
                    transform: function(source, options) {
                        return babel.transform(
                            source,
                            finalOptions
                        );
                    },
                },
                function (err, result) {
                    if (err) {
                        def.reject(err);
                    } else {
                        def.resolve({file : arg, result : result});
                    }
                }
            )

            return def.promise();

        })).then(function (res) {

            var usedHelpers = [],
                concatArgs = [];

            res.forEach(function(transform) {

                var node,
                    result = transform.result;
                    file = transform.file;

                if (result.metadata.usedHelpers) {
                    usedHelpers = uniqConcat(usedHelpers, result.metadata.usedHelpers);
                }

                if (result.map) {
                    concatArgs.push([file.fullname, result.code, result.map]);
                } else {
                    node = sourcemap.generate(file.fullname, result.code);
                    concatArgs.push([
                        sourcemap.normalizeFileName(file.fullname),
                        result.code,
                        JSON.parse(node.map.toString())
                    ]);
                }
            });

            var babelHelpers = babel.buildExternalHelpers(usedHelpers);
            var babelHelpersSourceMap = sourcemap.generate('babelHelpers.js', babelHelpers);
            var babelHelpersSourceMapEncoded = JSON.parse(babelHelpersSourceMap.map.toString());

            concat.add('babelHelpers.js', babelHelpers, babelHelpersSourceMapEncoded);

            concatArgs.forEach(function(arg) {
                concat.add.apply(concat, arg);
            });

            fs.writeFileSync(target + '.map', concat.sourceMap);
            return concat.content;
        });
    })
    .createTech();
